==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/trace/ui/internal/wizard/NewMonitorWizard.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.wizard;

import java.util.*;

import org.eclipse.hyades.trace.ui.*;
import org.eclipse.hyades.trace.internal.ui.*;
import org.eclipse.jface.wizard.*;
import org.eclipse.jface.viewers.*;
import org.eclipse.core.resources.*;
import org.eclipse.ui.*;

public class NewMonitorWizard extends Wizard implements INewWizard
{

  protected PDProjectExplorer fViewer;
  protected IStructuredSelection fSelection;
  protected IResource fResource;
  protected NewMonitorWizardPage fPage;

  public NewMonitorWizard()
  {
	setNeedsProgressMonitor(true);
  }  
  public void addPages()
  {
  	setWindowTitle(UIPlugin.getResourceString("MONITOR_WIZARD_TITLE"));	
	fPage = new NewMonitorWizardPage("com.ibm.etools.pd.core.wizard.NewMonitorPage",fResource);
	addPage(fPage);
  }  
/**
 * Insert the method's description here.
 * Creation date: (8/7/2001 4:25:43 PM)
 * @return com.ibm.etools.pd.core.PDProjectExplorer
 */
public PDProjectExplorer getViewer() {
	return fViewer;
}
  public void init(IWorkbench workbench, IStructuredSelection selection)
  {
	fSelection = selection;
	if (selection instanceof IStructuredSelection)
	{
	  Iterator enum = ((IStructuredSelection) selection).iterator();
	  if (enum.hasNext())
	  {
		Object cg = enum.next();
		if (cg instanceof IResource)
		{		
		  fResource = (IResource) cg;
		}
	  }
	}

	setDefaultPageImageDescriptor(UIPlugin.getImageDescriptor(PDPluginImages.IMG_UI_WZ_NEWMON));	
  }  
  public boolean performFinish()
  {
	if (fPage.finish())
	{	
	  fViewer.getViewer().refresh();			
	  fViewer.selectObject(fPage.getMonitor());		  
	 
	  return true;
	}
	return false;
  }  
  public void setViewer(PDProjectExplorer viewer)
  {
	fViewer = viewer;

	viewer.getViewer().createSelectedNodeChildren();	
  }  
}

==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/trace/ui/internal/wizard/NewMonitorWizard.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.wizard;

import java.util.*;

import org.eclipse.hyades.trace.ui.*;
import org.eclipse.hyades.trace.internal.ui.*;
import org.eclipse.jface.wizard.*;
import org.eclipse.jface.viewers.*;
import org.eclipse.core.resources.*;
import org.eclipse.ui.*;

public class NewMonitorWizard extends Wizard implements INewWizard
{

  protected PDProjectExplorer fViewer;
  protected IStructuredSelection fSelection;
  protected IResource fResource;
  protected NewMonitorWizardPage fPage;

  public NewMonitorWizard()
  {
	setNeedsProgressMonitor(true);
  }  
  public void addPages()
  {
  	setWindowTitle(UIPlugin.getResourceString("MONITOR_WIZARD_TITLE"));	
	fPage = new NewMonitorWizardPage("com.ibm.etools.pd.core.wizard.NewMonitorPage",fResource);
	addPage(fPage);
  }  
/**
 * Insert the method's description here.
 * Creation date: (8/7/2001 4:25:43 PM)
 * @return com.ibm.etools.pd.core.PDProjectExplorer
 */
public PDProjectExplorer getViewer() {
	return fViewer;
}
  public void init(IWorkbench workbench, IStructuredSelection selection)
  {
	fSelection = selection;
	if (selection instanceof IStructuredSelection)
	{
	  Iterator enum = ((IStructuredSelection) selection).iterator();
	  if (enum.hasNext())
	  {
		Object cg = enum.next();
		if (cg instanceof IResource)
		{		
		  fResource = (IResource) cg;
		}
	  }
	}

	setDefaultPageImageDescriptor(UIPlugin.getImageDescriptor(PDPluginImages.IMG_UI_WZ_NEWMON));	
  }  
  public boolean performFinish()
  {
	if (fPage.finish())
	{	
	  fViewer.getViewer().refresh();			
	  fViewer.selectObject(fPage.getMonitor());		  
	 
	  return true;
	}
	return false;
  }  
  public void setViewer(PDProjectExplorer viewer)
  {
	fViewer = viewer;

	((PDProjectViewer)viewer.getViewer()).createSelectedNodeChildren();	
  }  
}
